unit rDBGridSorter_ADO;

{<
  rDBGridSorter_ADO unit contains TrDBGridSorter_ADO - sorter for TCustomADODataSet
  used by rDBGrid to sort ADO datasets.

  @author(Rosinsky Software - <http://www.rosinsky.cz/delphi>)
  @created(Oct 2006 - Jun 2013)
  @lastmod(Feb 2023)
}

interface

uses
  Windows, Messages, SysUtils, Graphics, Classes, Controls, Menus, Dialogs,
  StdCtrls, Forms, DB, Variants, rDBGrid,
  Adodb;

type
  { Sorter for TCustomADODataSet - used by rDBGrid to sort ADO datasets }
  TrDBGridSorter_ADO = class(TrDBGridCustomSorter)
  protected
    function SetSort_CreateIndex(DataSet: TDataSet; const SortString: string; const SortFields: string; const DescendingFields: string): boolean; override;
    procedure DatasetRequery(DataSet: TDataSet); override;
  public
    { returns filter wildcard char for specified dataset type }
    function GetFilterWildCardChar: char; override;
    { returns filter like operator for specified dataset type }
    function GetFilterLikeOperator: string; override;
    { set filter case sensitivity options }
    function SetFilterCaseSensitivity(DataSet: TDataSet; FilterCaseSensitivity: TOptionFilterCaseSensitivityType): boolean; override;
  end;

procedure Register; {< @exclude }

implementation

{$R *.res}

uses RosiCompGlobalCfg;

procedure Register;
begin
  RegisterComponents('Rosi DB', [TrDBGridSorter_ADO]);
end;

function TrDBGridSorter_ADO.SetSort_CreateIndex(DataSet: TDataSet; const SortString: string; const SortFields: string; const DescendingFields: string): boolean;
var
  DS: TCustomADODataSet;
begin
  if (DataSet is TCustomADODataSet) then
  begin
    DS:=DataSet as TCustomADODataSet;
    DS.Sort:=SortString;
    Result:=true;
  end
  else
    Result:= inherited;
end;

procedure TrDBGridSorter_ADO.DatasetRequery(DataSet: TDataSet);
var
  DS: TCustomADODataSet;
begin
  if (DataSet is TCustomADODataSet) then
  begin
    DS:=DataSet as TCustomADODataSet;
    DS.Requery();
  end
  else
    inherited;
end;

function TrDBGridSorter_ADO.GetFilterWildCardChar: char;
begin
  Result:='*';
end;

function TrDBGridSorter_ADO.GetFilterLikeOperator: string;
begin
  Result:='LIKE';
end;

function TrDBGridSorter_ADO.SetFilterCaseSensitivity(DataSet: TDataSet; FilterCaseSensitivity: TOptionFilterCaseSensitivityType): boolean;
begin
  // FilterOptions is not supported for ADO, skip the action in all cases
  Result:=true;
end;

end.
